==> connector-packaging-persmidwife-3.16.1-java.zip: examples/be/fgov/ehealth/technicalconnector/tests/beid/domain/eidviewer/Card.java <==
/*
 * Copyright (c) eHealth
 */

package be.fgov.ehealth.technicalconnector.tests.beid.domain.eidviewer;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>
 * Java class for anonymous complex type.
 * 
 * <p>
 * The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="type" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="testCardVersion" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="friendlyName" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="chipNumber" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="physicalCardChipNumber" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="versionNumber" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="atr" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="file" maxOccurs="unbounded">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="id" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *                   &lt;element name="content" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "type", "testCardVersion", "friendlyName", "chipNumber", "physicalCardChipNumber", "versionNumber", "atr", "file"
})
@XmlRootElement(name = "card")
public class Card {

    @XmlElement(required = true)
    protected String type;

    @XmlElement(required = true)
    protected String testCardVersion;

    @XmlElement(required = true)
    protected String friendlyName;

    @XmlElement(required = true)
    protected String chipNumber;

    @XmlElement(required = true)
    protected String physicalCardChipNumber;

    @XmlElement(required = true)
    protected String versionNumber;

    @XmlElement(required = true)
    protected String atr;

    @XmlElement(required = true)
    protected List<File> file;

    /**
     * Gets the value of the type property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setType(String value) {
        this.type = value;
    }

    /**
     * Gets the value of the testCardVersion property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getTestCardVersion() {
        return testCardVersion;
    }

    /**
     * Sets the value of the testCardVersion property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setTestCardVersion(String value) {
        this.testCardVersion = value;
    }

    /**
     * Gets the value of the friendlyName property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getFriendlyName() {
        return friendlyName;
    }

    /**
     * Sets the value of the friendlyName property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setFriendlyName(String value) {
        this.friendlyName = value;
    }

    /**
     * Gets the value of the chipNumber property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getChipNumber() {
        return chipNumber;
    }

    /**
     * Sets the value of the chipNumber property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setChipNumber(String value) {
        this.chipNumber = value;
    }

    /**
     * Gets the value of the physicalCardChipNumber property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getPhysicalCardChipNumber() {
        return physicalCardChipNumber;
    }

    /**
     * Sets the value of the physicalCardChipNumber property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setPhysicalCardChipNumber(String value) {
        this.physicalCardChipNumber = value;
    }

    /**
     * Gets the value of the versionNumber property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getVersionNumber() {
        return versionNumber;
    }

    /**
     * Sets the value of the versionNumber property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setVersionNumber(String value) {
        this.versionNumber = value;
    }

    /**
     * Gets the value of the atr property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getAtr() {
        return atr;
    }

    /**
     * Sets the value of the atr property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setAtr(String value) {
        this.atr = value;
    }

    /**
     * Gets the value of the file property.
     * 
     * <p>
     * This accessor method returns a reference to the live list, not a snapshot. Therefore any modification you make to the returned list
     * will be present inside the JAXB object. This is why there is not a <CODE>set</CODE> method for the file property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * 
     * <pre>
     * getFile().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list {@link Card.File }
     * 
     * 
     */
    public List<File> getFile() {
        if (file == null) {
            file = new ArrayList<File>();
        }
        return this.file;
    }


   

}

==> connector-packaging-persmidwife-3.28.5-java.zip: examples/be/fgov/ehealth/technicalconnector/tests/beid/domain/eidviewer/Card.java <==
/*
 * Copyright (c) eHealth
 */

package be.fgov.ehealth.technicalconnector.tests.beid.domain.eidviewer;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.*;


/**
 * <p>
 * Java class for anonymous complex type.
 * 
 * <p>
 * The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="type" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="testCardVersion" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="friendlyName" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="chipNumber" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="physicalCardChipNumber" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="versionNumber" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="atr" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="file" maxOccurs="unbounded">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="id" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *                   &lt;element name="content" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {"type", "testCardVersion", "friendlyName", "chipNumber", "physicalCardChipNumber", "versionNumber", "atr", "file"})
@XmlRootElement(name = "card")
public class Card {

    @XmlElement(required = true)
    protected String type;

    @XmlElement(required = true)
    protected String testCardVersion;

    @XmlElement(required = true)
    protected String friendlyName;

    @XmlElement(required = true)
    protected String chipNumber;

    @XmlElement(required = true)
    protected String physicalCardChipNumber;

    @XmlElement(required = true)
    protected String versionNumber;

    @XmlElement(required = true)
    protected String atr;

    @XmlElement(required = true)
    protected List<File> file;

    /**
     * Gets the value of the type property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setType(String value) {
        this.type = value;
    }

    /**
     * Gets the value of the testCardVersion property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getTestCardVersion() {
        return testCardVersion;
    }

    /**
     * Sets the value of the testCardVersion property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setTestCardVersion(String value) {
        this.testCardVersion = value;
    }

    /**
     * Gets the value of the friendlyName property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getFriendlyName() {
        return friendlyName;
    }

    /**
     * Sets the value of the friendlyName property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setFriendlyName(String value) {
        this.friendlyName = value;
    }

    /**
     * Gets the value of the chipNumber property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getChipNumber() {
        return chipNumber;
    }

    /**
     * Sets the value of the chipNumber property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setChipNumber(String value) {
        this.chipNumber = value;
    }

    /**
     * Gets the value of the physicalCardChipNumber property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getPhysicalCardChipNumber() {
        return physicalCardChipNumber;
    }

    /**
     * Sets the value of the physicalCardChipNumber property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setPhysicalCardChipNumber(String value) {
        this.physicalCardChipNumber = value;
    }

    /**
     * Gets the value of the versionNumber property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getVersionNumber() {
        return versionNumber;
    }

    /**
     * Sets the value of the versionNumber property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setVersionNumber(String value) {
        this.versionNumber = value;
    }

    /**
     * Gets the value of the atr property.
     * 
     * @return possible object is {@link String }
     * 
     */
    public String getAtr() {
        return atr;
    }

    /**
     * Sets the value of the atr property.
     * 
     * @param value allowed object is {@link String }
     * 
     */
    public void setAtr(String value) {
        this.atr = value;
    }

    /**
     * Gets the value of the file property.
     * 
     * <p>
     * This accessor method returns a reference to the live list, not a snapshot. Therefore any modification you make to the returned list
     * will be present inside the JAXB object. This is why there is not a <CODE>set</CODE> method for the file property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * 
     * <pre>
     * getFile().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list {@link Card.File }
     * 
     * 
     */
    public List<File> getFile() {
        if (file == null) {
            file = new ArrayList<File>();
        }
        return this.file;
    }


}
